@@ -47,6 +47,9 @@ INTERNALERROR_DATABASEERROR = 'InternalError.DatabaseError'
 # 迁移任务冲突。
 INTERNALERROR_DUPLICATEJOB = 'InternalError.DuplicateJob'
 
+# http请求访问出错。
+INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
+
 # 内部组件访问错误。
 INTERNALERROR_INTERNALINNERCOMMONERROR = 'InternalError.InternalInnerCommonError'
 
@@ -80,6 +83,9 @@ INVALIDPARAMETERVALUE_DATACONVERTERROR = 'InvalidParameterValue.DataConvertError
 # 参数值错误。
 INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUE = 'InvalidParameterValue.InvalidParameterValue'
 
+# 非法参数。
+INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUEERROR = 'InvalidParameterValue.InvalidParameterValueError'
+
 # 闲置迁移任务数目超过限制。
 LIMITEXCEEDED_MAXUNUSEDJOBS = 'LimitExceeded.MaxUnusedJobs'
 
@@ -116,5 +122,5 @@ UNAUTHORIZEDOPERATION_NOTENOUGHPRIVILEGES = 'UnauthorizedOperation.NotEnoughPriv
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
-# 自研上云用户创建同步任务时未指定标签，需要补齐“运营部门”、“运营产品”、“负责人”这三类标签。
+# 自研上云用户创建迁移任务时未指定标签，需要补齐“运营部门”、“运营产品”、“负责人”这三类标签。
 UNSUPPORTEDOPERATION_INTRANETUSERNOTTAGGEDERROR = 'UnsupportedOperation.IntraNetUserNotTaggedError'
